Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1079)

Unified Diff: ios/web_view/internal/cwv_website_data_store.mm

Issue 2697453007: Rename CRIWVWebsiteDataStore to CWVWebsiteDataStore. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web_view/internal/cwv_web_view.mm ('k') | ios/web_view/internal/cwv_website_data_store_internal.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web_view/internal/cwv_website_data_store.mm
diff --git a/ios/web_view/internal/criwv_website_data_store.mm b/ios/web_view/internal/cwv_website_data_store.mm
similarity index 78%
rename from ios/web_view/internal/criwv_website_data_store.mm
rename to ios/web_view/internal/cwv_website_data_store.mm
index af9f59f186dc4f22b5024fd1a1d07a88737949d7..520da839af44cf27c5ce65cd59eb07047c2b17a6 100644
--- a/ios/web_view/internal/criwv_website_data_store.mm
+++ b/ios/web_view/internal/cwv_website_data_store.mm
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#import "ios/web_view/internal/criwv_website_data_store_internal.h"
+#import "ios/web_view/internal/cwv_website_data_store_internal.h"
#include <memory.h>
@@ -13,8 +13,8 @@
#error "This file requires ARC support."
#endif
-@implementation CRIWVWebsiteDataStore
-// TODO(crbug.com/690182): CRIWVWebsiteDataStore should own _browserState.
+@implementation CWVWebsiteDataStore
+// TODO(crbug.com/690182): CWVWebsiteDataStore should own _browserState.
ios_web_view::CRIWVBrowserState* _browserState;
- (BOOL)isPersistent {
@@ -31,7 +31,7 @@ ios_web_view::CRIWVBrowserState* _browserState;
}
+ (instancetype)defaultDataStore {
- CRIWVWebsiteDataStore* dataStore = [[CRIWVWebsiteDataStore alloc] init];
+ CWVWebsiteDataStore* dataStore = [[CWVWebsiteDataStore alloc] init];
ios_web_view::CRIWVWebClient* client =
static_cast<ios_web_view::CRIWVWebClient*>(web::GetWebClient());
@@ -41,7 +41,7 @@ ios_web_view::CRIWVBrowserState* _browserState;
}
+ (instancetype)nonPersistentDataStore {
- CRIWVWebsiteDataStore* dataStore = [[CRIWVWebsiteDataStore alloc] init];
+ CWVWebsiteDataStore* dataStore = [[CWVWebsiteDataStore alloc] init];
ios_web_view::CRIWVWebClient* client =
static_cast<ios_web_view::CRIWVWebClient*>(web::GetWebClient());
« no previous file with comments | « ios/web_view/internal/cwv_web_view.mm ('k') | ios/web_view/internal/cwv_website_data_store_internal.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698